Creates an object that encapsulates an exposure time-series with its
metadata, such as formatted datetime strings and file name where the
series was loaded from. no_exposure() is shorthand to create a time-series
of constant zero exposure.
ExposureSeries(series, dates, file, meta, context)an S4 object of type ExposureSeries
data.frame with two columns containing a time-series
vector, optional original list of time stamps
character, optional file name where data originates from
list, optional metadata
list optional contextual metadata such as project ids
datesoriginal time points of time-series, e.g. time stamps of the form 2000-01-01 12:00
filecharacter, file name where data originates from, may be empty
metalist, contains metadata
contextlist, contains contextual metadata, such as project ids
seriesdata.frame containing the actual time-series
no_exposure()